==> huaweicloudsdkcdn-3.1.83-py2.py3-none-any.whl: huaweicloudsdkcdn/v2/model/list_cdn_domain_top_refers_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCdnDomainTopRefersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'top_refer_summary': 'list[TopReferSummary]'
    }

    attribute_map = {
        'top_refer_summary': 'top_refer_summary'
    }

    def __init__(self, top_refer_summary=None):
        """ListCdnDomainTopRefersResponse

        The model defined in huaweicloud sdk

        :param top_refer_summary: 详情数据对象。
        :type top_refer_summary: list[:class:`huaweicloudsdkcdn.v2.TopReferSummary`]
        """
        
        super(ListCdnDomainTopRefersResponse, self).__init__()

        self._top_refer_summary = None
        self.discriminator = None

        if top_refer_summary is not None:
            self.top_refer_summary = top_refer_summary

    @property
    def top_refer_summary(self):
        """Gets the top_refer_summary of this ListCdnDomainTopRefersResponse.

        详情数据对象。

        :return: The top_refer_summary of this ListCdnDomainTopRefersResponse.
        :rtype: list[:class:`huaweicloudsdkcdn.v2.TopReferSummary`]
        """
        return self._top_refer_summary

    @top_refer_summary.setter
    def top_refer_summary(self, top_refer_summary):
        """Sets the top_refer_summary of this ListCdnDomainTopRefersResponse.

        详情数据对象。

        :param top_refer_summary: The top_refer_summary of this ListCdnDomainTopRefersResponse.
        :type top_refer_summary: list[:class:`huaweicloudsdkcdn.v2.TopReferSummary`]
        """
        self._top_refer_summary = top_refer_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCdnDomainTopRefersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.1.158-py2.py3-none-any.whl: huaweicloudsdkcdn/v2/model/list_cdn_domain_top_refers_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCdnDomainTopRefersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'top_refer_summary': 'list[TopReferSummary]'
    }

    attribute_map = {
        'top_refer_summary': 'top_refer_summary'
    }

    def __init__(self, top_refer_summary=None):
        r"""ListCdnDomainTopRefersResponse

        The model defined in huaweicloud sdk

        :param top_refer_summary: 详情数据对象。
        :type top_refer_summary: list[:class:`huaweicloudsdkcdn.v2.TopReferSummary`]
        """
        
        super(ListCdnDomainTopRefersResponse, self).__init__()

        self._top_refer_summary = None
        self.discriminator = None

        if top_refer_summary is not None:
            self.top_refer_summary = top_refer_summary

    @property
    def top_refer_summary(self):
        r"""Gets the top_refer_summary of this ListCdnDomainTopRefersResponse.

        详情数据对象。

        :return: The top_refer_summary of this ListCdnDomainTopRefersResponse.
        :rtype: list[:class:`huaweicloudsdkcdn.v2.TopReferSummary`]
        """
        return self._top_refer_summary

    @top_refer_summary.setter
    def top_refer_summary(self, top_refer_summary):
        r"""Sets the top_refer_summary of this ListCdnDomainTopRefersResponse.

        详情数据对象。

        :param top_refer_summary: The top_refer_summary of this ListCdnDomainTopRefersResponse.
        :type top_refer_summary: list[:class:`huaweicloudsdkcdn.v2.TopReferSummary`]
        """
        self._top_refer_summary = top_refer_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCdnDomainTopRefersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
